'use strict';

exports.__esModule = true;

var _BaseFormatter = require('./BaseFormatter');

var _BaseFormatter2 = _interopRequireDefault(_BaseFormatter);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class ErrorFormatter extends _BaseFormatter2.default {
	formatErrorStack(stack, depth) {
		const stackArray = stack.split('\n').slice(1).map(stackItem => {
			const formattedStackItem = stackItem.replace(`${process.cwd()}/`, this.config.baseDir).replace(/^\s*/g, `${this._buildIndentString(depth + 1)}`);

			if (stackItem.includes(process.cwd()) && !stackItem.includes('node_modules')) {
				return this.config.colors.stackHighlight(formattedStackItem);
			}

			return formattedStackItem;
		});
		return stackArray.join('');
	}

	/**
  * @param data
  * @param depth
  * @param formatVariable universal method dependency
  * @returns {string}
  */
	format(data, depth, formatVariable) {
		if (!(data instanceof Error)) {
			throw new Error('The type of value should be "Error"');
		}
		// stack can be present in different key
		const stackKey = Object.keys(data).find(key => {
			return (/^stack/.test(key) && typeof data[key] === 'string'
			);
		});

		if (stackKey) {
			// eslint-disable-next-line no-param-reassign
			data[stackKey] = this.formatErrorStack(data[stackKey], depth + 1);
		}

		const keyValuesString = formatVariable(Object.assign({
			message: data.message
		}, data), depth);

		return `${keyValuesString}` + `${this._buildIndentString(depth + 1)}` + `${this.config.colors.object.key('stack', 1)}: ${this.formatErrorStack(data.stack, depth + 1)}`;
	}
}
exports.default = ErrorFormatter;
//# sourceMappingURL=Error.js.map