'use strict';

exports.__esModule = true;

var _deepExtend = require('deep-extend');

var _deepExtend2 = _interopRequireDefault(_deepExtend);

var _config = require('./config');

var _config2 = _interopRequireDefault(_config);

var _OptionLine = require('./formatters/OptionLine');

var _OptionLine2 = _interopRequireDefault(_OptionLine);

var _Array = require('./formatters/Array');

var _Array2 = _interopRequireDefault(_Array);

var _Error = require('./formatters/Error');

var _Error2 = _interopRequireDefault(_Error);

var _Object = require('./formatters/Object');

var _Object2 = _interopRequireDefault(_Object);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const defaultFormatters = {
	OptionLineFormatter: _OptionLine2.default,
	ArrayFormatter: _Array2.default,
	ErrorFormatter: _Error2.default,
	ObjectFormatter: _Object2.default
};

const excludeDefaultKeysS = Symbol('excludeDefaultKeys');

class BunyanStdoutStream {
	constructor(config = {}, formatters = defaultFormatters) {
		const formattersClasses = Object.assign({}, defaultFormatters, formatters);
		this.config = (0, _deepExtend2.default)(_config2.default, config);

		this.optionLineFormatter = new formattersClasses.OptionLineFormatter(this.config);
		this.arrayFormatter = new formattersClasses.ArrayFormatter(this.config);
		this.errorFormatter = new formattersClasses.ErrorFormatter(this.config);
		this.objectFormatter = new formattersClasses.ObjectFormatter(this.config);

		// maybe extract as dependency
		this.stream = process.stdout;
	}

	[excludeDefaultKeysS](object) {
		return Object.keys(object).reduce((ob, key) => {
			if (this.config.excludeKeys.includes(key)) {
				return ob;
			}

			return Object.assign({}, ob, { [key]: object[key] });
		}, {});
	}

	formatVariable(variable, depth = 0) {
		if (depth === this.config.maxDepth) {
			return this.config.colors.object.system('Max depth');
		}

		if (Array.isArray(variable)) {
			return this.arrayFormatter.format(variable, depth, this.formatVariable.bind(this));
		}

		if (variable instanceof Error) {
			return this.errorFormatter.format(variable, depth, this.formatVariable.bind(this));
		}

		if (variable === null) {
			return this.config.colors.object.system('null');
		}

		if (typeof variable === 'undefined') {
			return this.config.colors.object.system('undefined');
		}

		if (typeof variable === 'function') {
			return this.config.colors.object.system('Function');
		}

		if (typeof variable === 'object') {
			return this.objectFormatter.format(variable, depth, this.formatVariable.bind(this));
		}

		if (typeof variable === 'string') {
			return `"${variable}"`;
		}

		return variable;
	}

	createStringFromVariable(data) {
		let resultString = '';
		const optionLine = this.optionLineFormatter.format(data);
		resultString = `${resultString}${optionLine}`;

		const objectForDisplay = this[excludeDefaultKeysS](data);
		if (Object.keys(objectForDisplay).length === 0) {
			return `${resultString}\n`;
		}

		resultString = `${resultString}${this.formatVariable(objectForDisplay, 0)}`;
		return `${resultString}\n`;
	}

	write(data) {
		this.stream.write(this.createStringFromVariable(data));
	}
}
exports.default = BunyanStdoutStream;
//# sourceMappingURL=index.js.map